yakumo.nova.v2.server_group

Package yakumo :: Package nova :: Package v2 :: Module server_group |
[hide private]
[frames] | no frames]

# Module server_group

source code

Resource class and its manager for server groups in Compute API v2

Classes | [hide private]
| Resource Resource class for server groups in Compute API v2
| Manager Manager class for server groups in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('policies'
      , 'policies', mapper.Noop), ('members', 'members', mapper.Noop), ('met
      adata', 'metadata', mapper.Noop),]